#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hscolour
version:              1.24.4
visibility:           public
id:                   hscolour-1.24.4-AWTcheqXyydDaCO4ylQ15z
key:                  hscolour-1.24.4-AWTcheqXyydDaCO4ylQ15z
license:              LicenseRef-LGPL
copyright:            2003-2017 Malcolm Wallace; 2006 Bjorn Bringert
maintainer:           Malcolm Wallace
author:               Malcolm Wallace
homepage:             http://code.haskell.org/~malcolm/hscolour/
synopsis:             Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.

category:             Language
abi:                  f779d43808b7ec28ed9deac4223ecb81
exposed:              True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hscolour-1.24.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hscolour-1.24.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hscolour
hs-libraries:         HShscolour-1.24.4-AWTcheqXyydDaCO4ylQ15z
depends:              base-4.14.2.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html:         /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

